// @flow

import React from 'react'
import cn from 'classnames'
import { themr } from 'react-css-themr'
import { Form } from 'react-form'
import TextInput from 'components/TextInput'

export const defaultStyles = {
  header: '',
  input: 'input-reset outline-0',
  submit: '',
}

const OptIn = ({
  data: {
    callToAction = 'Subscribe Now',
  } = {},
  requireName = false,
  nameLabel,
  emailLabel,
  phoneLabel,
  onSubmit,
  showErrors,
  onValidationFail,
  className,
  theme,
}: {
  data: {
    callToAction: string,
  },
  requireName: boolean,
  nameLabel?: string,
  emailLabel?: string,
  phoneLabel?: string,
  onSubmit: Function,
  onValidationFail?: Function,
  showErrors?: boolean,
  className?: string,
  theme: { [key: string]: string },
}) => {
  const inputTheme = {
    root: theme.inputWrapper,
    icon: theme.icon,
    input: theme.input,
  }
  return (
    <Form
      data-component="OptIn"
      onSubmit={onSubmit}
      onValidationFail={(...args) => onValidationFail && onValidationFail(...args)}
      validate={({ name, email, phone }) => {
        const errors = {
          email: !email ? 'Email is required' : undefined,
          phone: !phone ? 'Phone is required' : undefined,
          name: undefined,
        }
        if (requireName) {
          errors.name = !name ? 'Name is required' : undefined
        }
        return errors
      }}
    >
      {({ submitForm, getError }) => (
        <div className={cn(theme.root, className)}>
          <form
            className={theme.form}
            onSubmit={submitForm}
          >
            <div className={theme.body}>
              {requireName && (
                <TextInput
                  icon="fa-user"
                  className={cn('flex-auto w-100', theme.input)}
                  field="name"
                  placeholder={nameLabel}
                  theme={inputTheme}
                />
              )}
              <TextInput
                icon="fa-envelope-o"
                type="email"
                className={cn('flex-auto w-100', theme.input)}
                field="email"
                placeholder={emailLabel}
                theme={inputTheme}
              />
              <TextInput
                icon="fa-phone"
                type="phone"
                className={cn('flex-auto w-100', theme.input)}
                field="phone"
                placeholder={phoneLabel}
                theme={inputTheme}
              />
            </div>
            <div className={theme.submitWrapper}>
              <button className={theme.submit} type="submit">{callToAction}</button>
            </div>
          </form>
          {showErrors && (
            <div className={theme.errorWrapper}>
              {(requireName ? ['name'] : []).concat(['email', 'phone']).map(item => (
                <div
                  key={item}
                  className={theme.error}
                >
                  {getError(item)}
                </div>
              ))}
            </div>
          )}
        </div>
       )}
    </Form>
  )
}

OptIn.defaultProps = {
  className: null,
  nameLabel: 'Name',
  emailLabel: 'Email',
  phoneLabel: 'Phone',
  descriptionLabel: 'Description',
  submitLabel: 'Submit',
  onValidationFail: null,
  requireName: false,
  showErrors: false,
}

export default themr('OptIn', {}, { composeTheme: 'softly' })(OptIn)
